@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2024 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2024 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2025 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2025 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-plugins-comp-delay
  * Created on: 25 нояб. 2020 г.
@@ -25,7 +25,7 @@
 
 #define LSP_PLUGINS_COMP_DELAY_VERSION_MAJOR         1
 #define LSP_PLUGINS_COMP_DELAY_VERSION_MINOR         0
-#define LSP_PLUGINS_COMP_DELAY_VERSION_MICRO         28
+#define LSP_PLUGINS_COMP_DELAY_VERSION_MICRO         29
 
 #define LSP_PLUGINS_COMP_DELAY_VERSION  \
     LSP_MODULE_VERSION( \
@@ -59,17 +59,17 @@ namespace lsp
             // Input controls
             BYPASS,
 
-            COMBO("mode", "Mode", 0, comp_delay_modes),
-            SWITCH("ramp", "Ramping", 0.0f),
-            INT_CONTROL("samp", "Samples", U_SAMPLES, comp_delay::SAMPLES),
-            INT_CONTROL("m", "Meters", U_M, comp_delay::METERS),
-            CONTROL("cm", "Centimeters", U_CM, comp_delay::CENTIMETERS),
-            CONTROL("t", "Temperature", U_DEG_CEL, comp_delay::TEMPERATURE),
-            CONTROL("time", "Time", U_MSEC, comp_delay::TIME),
+            COMBO("mode", "Mode", "Mode", 0, comp_delay_modes),
+            SWITCH("ramp", "Ramping", "Ramping", 0.0f),
+            INT_CONTROL("samp", "Samples", "Samples", U_SAMPLES, comp_delay::SAMPLES),
+            INT_CONTROL("m", "Meters", "Meters", U_M, comp_delay::METERS),
+            CONTROL("cm", "Centimeters", "Centimeters", U_CM, comp_delay::CENTIMETERS),
+            CONTROL("t", "Temperature", "Temperature", U_DEG_CEL, comp_delay::TEMPERATURE),
+            CONTROL("time", "Time", "Time", U_MSEC, comp_delay::TIME),
             DRY_GAIN(0.0f),
             WET_GAIN(1.0f),
             DRYWET(100.0f),
-            SWITCH("phase", "Phase Invert", 0.0f),
+            SWITCH("phase", "Phase Invert", "Phase", 0.0f),
 
             OUT_GAIN,
 
@@ -94,18 +94,18 @@ namespace lsp
             // Input controls
             BYPASS,
 
-            COMBO("mode", "Mode", 0, comp_delay_modes),
-            SWITCH("ramp", "Ramping", 0.0f),
-            INT_CONTROL("samp", "Samples", U_SAMPLES, comp_delay::SAMPLES),
-            INT_CONTROL("m", "Meters", U_M, comp_delay::METERS),
-            CONTROL("cm", "Centimeters", U_CM, comp_delay::CENTIMETERS),
-            CONTROL("t", "Temperature", U_DEG_CEL, comp_delay::TEMPERATURE),
-            CONTROL("time", "Time", U_MSEC, comp_delay::TIME),
+            COMBO("mode", "Mode", "Mode", 0, comp_delay_modes),
+            SWITCH("ramp", "Ramping", "Ramping", 0.0f),
+            INT_CONTROL("samp", "Samples", "Samples", U_SAMPLES, comp_delay::SAMPLES),
+            INT_CONTROL("m", "Meters", "Meters", U_M, comp_delay::METERS),
+            CONTROL("cm", "Centimeters", "Centimeters", U_CM, comp_delay::CENTIMETERS),
+            CONTROL("t", "Temperature", "Temperature", U_DEG_CEL, comp_delay::TEMPERATURE),
+            CONTROL("time", "Time", "Time", U_MSEC, comp_delay::TIME),
             DRY_GAIN(0.0f),
             WET_GAIN(1.0f),
             DRYWET(100.0f),
-            SWITCH("phase_l", "Phase Invert Left", 0.0f),
-            SWITCH("phase_r", "Phase Invert Right", 0.0f),
+            SWITCH("phase_l", "Phase Invert Left", "Phase L", 0.0f),
+            SWITCH("phase_r", "Phase Invert Right", "Phase R", 0.0f),
 
             OUT_GAIN,
 
@@ -130,29 +130,29 @@ namespace lsp
             // Input controls
             BYPASS,
 
-            COMBO("mode_l", "Mode Left", 0, comp_delay_modes),
-            SWITCH("ramp_l", "Ramping Left", 0.0f),
-            INT_CONTROL("samp_l", "Samples Left", U_SAMPLES, comp_delay::SAMPLES),
-            INT_CONTROL("m_l", "Meters Left", U_M, comp_delay::METERS),
-            CONTROL("cm_l", "Centimeters Left", U_CM, comp_delay::CENTIMETERS),
-            CONTROL("t_l", "Temperature Left", U_DEG_CEL, comp_delay::TEMPERATURE),
-            CONTROL("time_l", "Time Left", U_MSEC, comp_delay::TIME),
+            COMBO("mode_l", "Mode Left", "Mode L", 0, comp_delay_modes),
+            SWITCH("ramp_l", "Ramping Left", "Ramping L", 0.0f),
+            INT_CONTROL("samp_l", "Samples Left", "Samples L", U_SAMPLES, comp_delay::SAMPLES),
+            INT_CONTROL("m_l", "Meters Left", "Meters L", U_M, comp_delay::METERS),
+            CONTROL("cm_l", "Centimeters Left", "Centimeters L", U_CM, comp_delay::CENTIMETERS),
+            CONTROL("t_l", "Temperature Left", "Temperature L", U_DEG_CEL, comp_delay::TEMPERATURE),
+            CONTROL("time_l", "Time Left", "Time L", U_MSEC, comp_delay::TIME),
             DRY_GAIN_L(0.0f),
             WET_GAIN_L(1.0f),
             DRYWET_L(100.0f),
-            SWITCH("phase_l", "Phase Invert Left", 0.0f),
+            SWITCH("phase_l", "Phase Invert Left", "Phase L", 0.0f),
 
-            COMBO("mode_r", "Mode Right", 0, comp_delay_modes),
-            SWITCH("ramp_r", "Ramping Right", 0.0f),
-            INT_CONTROL("samp_r", "Samples Right", U_SAMPLES, comp_delay::SAMPLES),
-            INT_CONTROL("m_r", "Meters Right", U_M, comp_delay::METERS),
-            CONTROL("cm_r", "Centimeters Right", U_CM, comp_delay::CENTIMETERS),
-            CONTROL("t_r", "Temperature Right", U_DEG_CEL, comp_delay::TEMPERATURE),
-            CONTROL("time_r", "Time Right", U_MSEC, comp_delay::TIME),
+            COMBO("mode_r", "Mode Right", "Mode R", 0, comp_delay_modes),
+            SWITCH("ramp_r", "Ramping Right", "Ramping R", 0.0f),
+            INT_CONTROL("samp_r", "Samples Right", "Samples R", U_SAMPLES, comp_delay::SAMPLES),
+            INT_CONTROL("m_r", "Meters Right", "Meters R", U_M, comp_delay::METERS),
+            CONTROL("cm_r", "Centimeters Right", "Centimeters R", U_CM, comp_delay::CENTIMETERS),
+            CONTROL("t_r", "Temperature Right", "Temperature R", U_DEG_CEL, comp_delay::TEMPERATURE),
+            CONTROL("time_r", "Time Right", "Time R", U_MSEC, comp_delay::TIME),
             DRY_GAIN_R(0.0f),
             WET_GAIN_R(1.0f),
             DRYWET_R(100.0f),
-            SWITCH("phase_r", "Phase Invert Right", 0.0f),
+            SWITCH("phase_r", "Phase Invert Right", "Phase R", 0.0f),
 
             OUT_GAIN,
 
