@@ -53,8 +53,41 @@ keeping the same settings for the left and right channels.</p>
 	<li><b>In<?= $sm ?></b> - enables drawing of compressor's input signal graph and corresponding level meter.</li>
 	<li><b>Out<?= $sm ?></b> - enables drawing of compressor's output signal graph and corresponding level meter.</li>
 	<li><b>Link</b> - the name of the shared memory link to pass sidechain signal.</li>
+	<li><b>Sidechain</b> - shows the sidechain control overlay.</li>
+	<li><b>Mix</b> - shows the Dry/Wet control overlay.</li>
 </ul>
-<p><b>'Sidechain' section:</b></p>
+
+<p><b>'Compressor' section:</b></p>
+<ul>
+	<li><b>Mode</b> - compression mode</li>
+	<ul>
+		<li><b>Downward (Down)</b> - the downward compressor.</li>
+		<li><b>Upward (Up)</b> - the upward compressor.</li>
+		<li><b>Boosting (Boost)</b> - the boosting compressor (upward with precise boost control).</li>
+	</ul>
+	<li><b>Ratio</b> - compression ratio.</li>
+	<li><b>Knee</b> - size of compression knee.</li>
+	<li><b>Makeup</b> - additional amplification gain after compression stage.</li>
+	<li><b>Boost</b> - this knob is related to <b>upward</b> and <b>boosting</b> compression modes only.
+		For <b>upward</b> mode it defines the threshold below which the constant amplification will be applied to the input signal.
+		This prevents compressor from applying infinite amplification to very quiet signals.
+		For <b>boosting</b> mode it defines the overall boost of the signal. The boost threshold is computed automatically. 
+	</li>
+	<li><b>Attack Thresh</b> - threshold of the compressor, placed in the middle of the knee.</li>
+	<li><b>Attack Time</b> - attack time of the compressor.</li>
+	<li><b>Release Thresh</b> - relative to the <b>Attack Thresh</b> threshold that sets up the threshold of <b>Release Time</b>.
+		If the current compressor's envelope value is below the configured <b>Release Threshold</b>, the release time is
+		being considered to be the same to the <b>attack time</b>.</li>
+	<li><b>Release Time</b> - release time of the compressor.</li>
+	<li><b>Hold</b> - the time period the envelope holds it's maximum value before starting the release.</li>
+</ul>
+<p><b>'Signal' section:</b></p>
+<ul>
+	<li><b>Input</b> - overall input gain.</li>
+	<li><b>Output</b> - overall output gain.</li>
+</ul>
+
+<p><b>Sidechain control overlay:</b></p>
 <ul>
 	<?php if (!$tt) { ?>
 	<li><b>Position</b> - the position of the sidechain input. Available variants:</li>
@@ -106,36 +139,10 @@ keeping the same settings for the left and right channels.</p>
 	<li><b>LPF</b> - allows to set up slope and cut-off frequency for the low-pass filter applied to sidechain signal.</li>
 	<li><b>HPF</b> - allows to set up slope and cut-off frequency for the high-pass filter applied to sidechain signal.</li>
 </ul>
-<p><b>'Compressor' section:</b></p>
+<p><b>Dry/Wet mix control overlay:</b></p>
 <ul>
-	<li><b>Mode</b> - compression mode</li>
-	<ul>
-		<li><b>Downward (Down)</b> - the downward compressor.</li>
-		<li><b>Upward (Up)</b> - the upward compressor.</li>
-		<li><b>Boosting (Boost)</b> - the boosting compressor (upward with precise boost control).</li>
-	</ul>
-	<li><b>Ratio</b> - compression ratio.</li>
-	<li><b>Knee</b> - size of compression knee.</li>
-	<li><b>Makeup</b> - additional amplification gain after compression stage.</li>
-	<li><b>Boost</b> - this knob is related to <b>upward</b> and <b>boosting</b> compression modes only.
-		For <b>upward</b> mode it defines the threshold below which the constant amplification will be applied to the input signal.
-		This prevents compressor from applying infinite amplification to very quiet signals.
-		For <b>boosting</b> mode it defines the overall boost of the signal. The boost threshold is computed automatically. 
-	</li>
-	<li><b>Attack Thresh</b> - threshold of the compressor, placed in the middle of the knee.</li>
-	<li><b>Attack Time</b> - attack time of the compressor.</li>
-	<li><b>Release Thresh</b> - relative to the <b>Attack Thresh</b> threshold that sets up the threshold of <b>Release Time</b>.
-		If the current compressor's envelope value is below the configured <b>Release Threshold</b>, the release time is
-		being considered to be the same to the <b>attack time</b>.</li>
-	<li><b>Release Time</b> - release time of the compressor.</li>
-	<li><b>Hold</b> - the time period the envelope holds it's maximum value before starting the release.</li>
 	<li><b>Mix Dry</b> - the amount of dry (unprocessed) signal, useful for parallel compression.</li>
 	<li><b>Mix Wet</b> - the amount of wet (processed) signal, useful for parallel compression.</li>
 	<li><b>Mix Dry/Wet</b> - the knob that controls this balance between mixed dry and wet signal (see <b>Mix Dry</b> and <b>Mix Wet</b>) and the dry (unprocessed) signal.</li>
 </ul>
 
-<p><b>'Signal' section:</b></p>
-<ul>
-	<li><b>Input</b> - overall input gain.</li>
-	<li><b>Output</b> - overall output gain.</li>
-</ul>
\ No newline at end of file
