@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2024 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2024 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2025 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2025 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-plugins-dyna-processor
  * Created on: 3 авг. 2021 г.
@@ -268,6 +268,8 @@ namespace lsp
             BIND_PORT(pBypass);
             BIND_PORT(pInGain);
             BIND_PORT(pOutGain);
+            SKIP_PORT("Show mix overlay");
+            SKIP_PORT("Show sidechain overlay");
             BIND_PORT(pPause);
             BIND_PORT(pClear);
             if ((nMode == DYNA_LR) || (nMode == DYNA_MS))
