@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2024 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2024 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2025 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2025 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-plugins-expander
  * Created on: 3 авг. 2021 г.
@@ -25,7 +25,7 @@
 
 #define LSP_PLUGINS_EXPANDER_VERSION_MAJOR       1
 #define LSP_PLUGINS_EXPANDER_VERSION_MINOR       0
-#define LSP_PLUGINS_EXPANDER_VERSION_MICRO       28
+#define LSP_PLUGINS_EXPANDER_VERSION_MICRO       29
 
 #define LSP_PLUGINS_EXPANDER_VERSION  \
     LSP_MODULE_VERSION( \
@@ -84,8 +84,8 @@ namespace lsp
 
         static const port_item_t exp_extsc_type[] =
         {
-            { "Internal",   "sidechain.internal"        },
             { "External",   "sidechain.external"        },
+            { "Internal",   "sidechain.internal"        },
             { "Link",       "sidechain.link"            },
             { NULL, NULL }
         };
@@ -110,16 +110,18 @@ namespace lsp
             BYPASS,             \
             IN_GAIN,            \
             OUT_GAIN,           \
-            SWITCH("pause", "Pause graph analysis", 0.0f), \
-            TRIGGER("clear", "Clear graph analysis")
+            SWITCH("showmx", "Show mix overlay", "Show mix bar", 0.0f), \
+            SWITCH("showsc", "Show sidechain overlay", "Show SC bar", 0.0f), \
+            SWITCH("pause", "Pause graph analysis", "Pause", 0.0f), \
+            TRIGGER("clear", "Clear graph analysis", "Clear")
 
         #define EXP_MS_COMMON  \
             EXP_COMMON,        \
-            SWITCH("msl", "Mid/Side listen", 0.0f)
+            SWITCH("msl", "Mid/Side listen", "M/S listen", 0.0f)
 
         #define EXP_SPLIT_COMMON \
-            SWITCH("ssplit", "Stereo split", 0.0f), \
-            COMBO("sscs", "Split sidechain source", expander_metadata::SC_SPLIT_SOURCE_DFL, exp_sc_split_sources)
+            SWITCH("ssplit", "Stereo split", "Stereo split", 0.0f), \
+            COMBO("sscs", "Split sidechain source", "Split SC source", expander_metadata::SC_SPLIT_SOURCE_DFL, exp_sc_split_sources)
 
         #define EXP_SHM_LINK_MONO \
             OPT_RETURN_MONO("link", "shml", "Side-chain shared memory link")
@@ -128,52 +130,52 @@ namespace lsp
             OPT_RETURN_STEREO("link", "shml_", "Side-chain shared memory link")
 
         #define EXP_MONO_CHANNEL(sc_type) \
-            COMBO("sci", "Sidechain input", expander_metadata::SC_TYPE_DFL, sc_type), \
-            COMBO("scm", "Sidechain mode", expander_metadata::SC_MODE_DFL, exp_sc_modes), \
-            CONTROL("sla", "Sidechain lookahead", U_MSEC, expander_metadata::LOOKAHEAD), \
-            SWITCH("scl", "Sidechain listen", 0.0f), \
-            LOG_CONTROL("scr", "Sidechain reactivity", U_MSEC, expander_metadata::REACTIVITY), \
-            AMP_GAIN100("scp", "Sidechain preamp", GAIN_AMP_0_DB), \
-            COMBO("shpm", "High-pass filter mode", 0, exp_filter_slope),      \
-            LOG_CONTROL("shpf", "High-pass filter frequency", U_HZ, expander_metadata::HPF),   \
-            COMBO("slpm", "Low-pass filter mode", 0, exp_filter_slope),      \
-            LOG_CONTROL("slpf", "Low-pass filter frequency", U_HZ, expander_metadata::LPF)
+            COMBO("sci", "Sidechain input", "SC input", expander_metadata::SC_TYPE_DFL, sc_type), \
+            COMBO("scm", "Sidechain mode", "SC mode", expander_metadata::SC_MODE_DFL, exp_sc_modes), \
+            CONTROL("sla", "Sidechain lookahead", "SC look", U_MSEC, expander_metadata::LOOKAHEAD), \
+            SWITCH("scl", "Sidechain listen", "SC listen", 0.0f), \
+            LOG_CONTROL("scr", "Sidechain reactivity", "SC react", U_MSEC, expander_metadata::REACTIVITY), \
+            AMP_GAIN100("scp", "Sidechain preamp", "SC preamp", GAIN_AMP_0_DB), \
+            COMBO("shpm", "High-pass filter mode", "HPF mode", 0, exp_filter_slope),      \
+            LOG_CONTROL("shpf", "High-pass filter frequency", "HPF freq", U_HZ, expander_metadata::HPF),   \
+            COMBO("slpm", "Low-pass filter mode", "LPF mode", 0, exp_filter_slope),      \
+            LOG_CONTROL("slpf", "Low-pass filter frequency", "LPF freq", U_HZ, expander_metadata::LPF)
 
-        #define EXP_STEREO_CHANNEL(id, label, sc_type) \
-            COMBO("sci" id, "Sidechain input" label, expander_metadata::SC_TYPE_DFL, sc_type), \
-            COMBO("scm" id, "Sidechain mode" label, expander_metadata::SC_MODE_DFL, exp_sc_modes), \
-            CONTROL("sla" id, "Sidechain lookahead" label, U_MSEC, expander_metadata::LOOKAHEAD), \
-            SWITCH("scl" id, "Sidechain listen" label, 0.0f), \
-            COMBO("scs" id, "Sidechain source" label, expander_metadata::SC_SOURCE_DFL, exp_sc_sources), \
-            LOG_CONTROL("scr" id, "Sidechain reactivity" label, U_MSEC, expander_metadata::REACTIVITY), \
-            AMP_GAIN100("scp" id, "Sidechain preamp" label, GAIN_AMP_0_DB), \
-            COMBO("shpm" id, "High-pass filter mode" label, 0, exp_filter_slope),      \
-            LOG_CONTROL("shpf" id, "High-pass filter frequency" label, U_HZ, expander_metadata::HPF),   \
-            COMBO("slpm" id, "Low-pass filter mode" label, 0, exp_filter_slope),      \
-            LOG_CONTROL("slpf" id, "Low-pass filter frequency" label, U_HZ, expander_metadata::LPF)
+        #define EXP_STEREO_CHANNEL(id, label, alias, sc_type) \
+            COMBO("sci" id, "Sidechain input" label, "SC input" alias, expander_metadata::SC_TYPE_DFL, sc_type), \
+            COMBO("scm" id, "Sidechain mode" label, "SC mode" alias, expander_metadata::SC_MODE_DFL, exp_sc_modes), \
+            CONTROL("sla" id, "Sidechain lookahead" label, "SC look" alias, U_MSEC, expander_metadata::LOOKAHEAD), \
+            SWITCH("scl" id, "Sidechain listen" label, "SC listen" alias, 0.0f), \
+            COMBO("scs" id, "Sidechain source" label, "SC source" alias, expander_metadata::SC_SOURCE_DFL, exp_sc_sources), \
+            LOG_CONTROL("scr" id, "Sidechain reactivity" label, "SC react" alias, U_MSEC, expander_metadata::REACTIVITY), \
+            AMP_GAIN100("scp" id, "Sidechain preamp" label, "SC preamp" alias, GAIN_AMP_0_DB), \
+            COMBO("shpm" id, "High-pass filter mode" label, "HPF mode" alias, 0, exp_filter_slope),      \
+            LOG_CONTROL("shpf" id, "High-pass filter frequency" label, "HPF freq" alias, U_HZ, expander_metadata::HPF),   \
+            COMBO("slpm" id, "Low-pass filter mode" label, "LPF mode" alias, 0, exp_filter_slope),      \
+            LOG_CONTROL("slpf" id, "Low-pass filter frequency" label, "LPF freq" alias, U_HZ, expander_metadata::LPF)
 
-        #define EXP_CHANNEL(id, label) \
-            COMBO("em" id, "Expander mode" label, expander_metadata::EM_DEFAULT, exp_modes), \
-            LOG_CONTROL("al" id, "Attack threshold" label, U_GAIN_AMP, expander_metadata::ATTACK_LVL), \
-            LOG_CONTROL("at" id, "Attack time" label, U_MSEC, expander_metadata::ATTACK_TIME), \
-            LOG_CONTROL("rrl" id, "Release threshold" label, U_GAIN_AMP, expander_metadata::RELEASE_LVL), \
-            LOG_CONTROL("rt" id, "Release time" label, U_MSEC, expander_metadata::RELEASE_TIME), \
-            CONTROL("hold" id, "Hold time" label, U_MSEC, expander_metadata::HOLD_TIME), \
-            LOG_CONTROL("er" id, "Ratio" label, U_NONE, expander_metadata::RATIO), \
-            LOG_CONTROL("kn" id, "Knee" label, U_GAIN_AMP, expander_metadata::KNEE), \
-            LOG_CONTROL("mk" id, "Makeup gain" label, U_GAIN_AMP, expander_metadata::MAKEUP), \
-            AMP_GAIN10("cdr" id, "Dry gain" label, GAIN_AMP_M_INF_DB),     \
-            AMP_GAIN10("cwt" id, "Wet gain" label, GAIN_AMP_0_DB), \
-            PERCENTS("cdw" id, "Dry/Wet balance" label, 100.0f, 0.1f), \
+        #define EXP_CHANNEL(id, label, alias) \
+            COMBO("em" id, "Expander mode" label, "Mode" alias, expander_metadata::EM_DEFAULT, exp_modes), \
+            LOG_CONTROL("al" id, "Attack threshold" label, "Att lvl" alias, U_GAIN_AMP, expander_metadata::ATTACK_LVL), \
+            LOG_CONTROL("at" id, "Attack time" label, "Att time" alias, U_MSEC, expander_metadata::ATTACK_TIME), \
+            LOG_CONTROL("rrl" id, "Release threshold" label, "Rel lvl" alias, U_GAIN_AMP, expander_metadata::RELEASE_LVL), \
+            LOG_CONTROL("rt" id, "Release time" label, "Rel time" alias, U_MSEC, expander_metadata::RELEASE_TIME), \
+            CONTROL("hold" id, "Hold time" label, "Hold time" alias, U_MSEC, expander_metadata::HOLD_TIME), \
+            LOG_CONTROL("er" id, "Ratio" label, "Ratio" alias, U_NONE, expander_metadata::RATIO), \
+            LOG_CONTROL("kn" id, "Knee" label, "Knee" alias, U_GAIN_AMP, expander_metadata::KNEE), \
+            LOG_CONTROL("mk" id, "Makeup gain" label, "Makeup" alias, U_GAIN_AMP, expander_metadata::MAKEUP), \
+            AMP_GAIN10("cdr" id, "Dry gain" label, "Dry" alias, GAIN_AMP_M_INF_DB),     \
+            AMP_GAIN10("cwt" id, "Wet gain" label, "Wet" alias, GAIN_AMP_0_DB), \
+            PERCENTS("cdw" id, "Dry/Wet balance" label, "Dry/Wet" alias, 100.0f, 0.1f), \
             METER_OUT_GAIN("rl" id, "Release level" label, 20.0f), \
             MESH("ecg" id, "Expander curve graph" label, 2, expander_metadata::CURVE_MESH_SIZE)
 
-        #define EXP_AUDIO_METER(id, label) \
-            SWITCH("slv" id, "Sidechain level visibility" label, 1.0f), \
-            SWITCH("elv" id, "Envelope level visibility" label, 1.0f), \
-            SWITCH("grv" id, "Gain reduction visibility" label, 1.0f), \
-            SWITCH("ilv" id, "Input level visibility" label, 1.0f), \
-            SWITCH("olv" id, "Output level visibility" label, 1.0f), \
+        #define EXP_AUDIO_METER(id, label, alias) \
+            SWITCH("slv" id, "Sidechain level visibility" label, "Show SC" alias, 1.0f), \
+            SWITCH("elv" id, "Envelope level visibility" label, "Show Env" alias, 1.0f), \
+            SWITCH("grv" id, "Gain reduction visibility" label, "Show Gain" alias, 1.0f), \
+            SWITCH("ilv" id, "Input level visibility" label, "Show In" alias, 1.0f), \
+            SWITCH("olv" id, "Output level visibility" label, "Show Out" alias, 1.0f), \
             MESH("scg" id, "Expander sidechain graph" label, 2, expander_metadata::TIME_MESH_SIZE), \
             MESH("evg" id, "Expander envelope graph" label, 2, expander_metadata::TIME_MESH_SIZE), \
             MESH("grg" id, "Expander gain reduciton" label, 2, expander_metadata::TIME_MESH_SIZE + 4), \
@@ -192,8 +194,8 @@ namespace lsp
             EXP_SHM_LINK_MONO,
             EXP_COMMON,
             EXP_MONO_CHANNEL(exp_sc_type),
-            EXP_CHANNEL("", ""),
-            EXP_AUDIO_METER("", ""),
+            EXP_CHANNEL("", "", ""),
+            EXP_AUDIO_METER("", "", ""),
 
             PORTS_END
         };
@@ -204,10 +206,10 @@ namespace lsp
             EXP_SHM_LINK_STEREO,
             EXP_COMMON,
             EXP_SPLIT_COMMON,
-            EXP_STEREO_CHANNEL("", "", exp_sc_type),
-            EXP_CHANNEL("", ""),
-            EXP_AUDIO_METER("_l", " Left"),
-            EXP_AUDIO_METER("_r", " Right"),
+            EXP_STEREO_CHANNEL("", "", "", exp_sc_type),
+            EXP_CHANNEL("", "", ""),
+            EXP_AUDIO_METER("_l", " Left", " L"),
+            EXP_AUDIO_METER("_r", " Right", " R"),
 
             PORTS_END
         };
@@ -217,12 +219,12 @@ namespace lsp
             PORTS_STEREO_PLUGIN,
             EXP_SHM_LINK_STEREO,
             EXP_COMMON,
-            EXP_STEREO_CHANNEL("_l", " Left", exp_sc_type),
-            EXP_STEREO_CHANNEL("_r", " Right", exp_sc_type),
-            EXP_CHANNEL("_l", " Left"),
-            EXP_CHANNEL("_r", " Right"),
-            EXP_AUDIO_METER("_l", " Left"),
-            EXP_AUDIO_METER("_r", " Right"),
+            EXP_STEREO_CHANNEL("_l", " Left", " L", exp_sc_type),
+            EXP_STEREO_CHANNEL("_r", " Right", " R", exp_sc_type),
+            EXP_CHANNEL("_l", " Left", " L"),
+            EXP_CHANNEL("_r", " Right", " R"),
+            EXP_AUDIO_METER("_l", " Left", " L"),
+            EXP_AUDIO_METER("_r", " Right", " R"),
 
             PORTS_END
         };
@@ -232,12 +234,12 @@ namespace lsp
             PORTS_STEREO_PLUGIN,
             EXP_SHM_LINK_STEREO,
             EXP_MS_COMMON,
-            EXP_STEREO_CHANNEL("_m", " Mid", exp_sc_type),
-            EXP_STEREO_CHANNEL("_s", " Side", exp_sc_type),
-            EXP_CHANNEL("_m", " Mid"),
-            EXP_CHANNEL("_s", " Side"),
-            EXP_AUDIO_METER("_m", " Mid"),
-            EXP_AUDIO_METER("_s", " Side"),
+            EXP_STEREO_CHANNEL("_m", " Mid", " M", exp_sc_type),
+            EXP_STEREO_CHANNEL("_s", " Side", " S", exp_sc_type),
+            EXP_CHANNEL("_m", " Mid", " M"),
+            EXP_CHANNEL("_s", " Side", " S"),
+            EXP_AUDIO_METER("_m", " Mid", " M"),
+            EXP_AUDIO_METER("_s", " Side", " S"),
 
             PORTS_END
         };
@@ -249,8 +251,8 @@ namespace lsp
             EXP_SHM_LINK_MONO,
             EXP_COMMON,
             EXP_MONO_CHANNEL(exp_extsc_type),
-            EXP_CHANNEL("", ""),
-            EXP_AUDIO_METER("", ""),
+            EXP_CHANNEL("", "", ""),
+            EXP_AUDIO_METER("", "", ""),
 
             PORTS_END
         };
@@ -262,10 +264,10 @@ namespace lsp
             EXP_SHM_LINK_STEREO,
             EXP_COMMON,
             EXP_SPLIT_COMMON,
-            EXP_STEREO_CHANNEL("", "", exp_extsc_type),
-            EXP_CHANNEL("", ""),
-            EXP_AUDIO_METER("_l", " Left"),
-            EXP_AUDIO_METER("_r", " Right"),
+            EXP_STEREO_CHANNEL("", "", "", exp_extsc_type),
+            EXP_CHANNEL("", "", ""),
+            EXP_AUDIO_METER("_l", " Left", " L"),
+            EXP_AUDIO_METER("_r", " Right", " R"),
 
             PORTS_END
         };
@@ -276,12 +278,12 @@ namespace lsp
             PORTS_STEREO_SIDECHAIN,
             EXP_SHM_LINK_STEREO,
             EXP_COMMON,
-            EXP_STEREO_CHANNEL("_l", " Left", exp_extsc_type),
-            EXP_STEREO_CHANNEL("_r", " Right", exp_extsc_type),
-            EXP_CHANNEL("_l", " Left"),
-            EXP_CHANNEL("_r", " Right"),
-            EXP_AUDIO_METER("_l", " Left"),
-            EXP_AUDIO_METER("_r", " Right"),
+            EXP_STEREO_CHANNEL("_l", " Left", " L", exp_extsc_type),
+            EXP_STEREO_CHANNEL("_r", " Right", " R", exp_extsc_type),
+            EXP_CHANNEL("_l", " Left", " L"),
+            EXP_CHANNEL("_r", " Right", " R"),
+            EXP_AUDIO_METER("_l", " Left", " L"),
+            EXP_AUDIO_METER("_r", " Right", " R"),
 
             PORTS_END
         };
@@ -292,12 +294,12 @@ namespace lsp
             PORTS_STEREO_SIDECHAIN,
             EXP_SHM_LINK_STEREO,
             EXP_MS_COMMON,
-            EXP_STEREO_CHANNEL("_m", " Mid", exp_extsc_type),
-            EXP_STEREO_CHANNEL("_s", " Side", exp_extsc_type),
-            EXP_CHANNEL("_m", " Mid"),
-            EXP_CHANNEL("_s", " Side"),
-            EXP_AUDIO_METER("_m", " Mid"),
-            EXP_AUDIO_METER("_s", " Side"),
+            EXP_STEREO_CHANNEL("_m", " Mid", " M", exp_extsc_type),
+            EXP_STEREO_CHANNEL("_s", " Side", " S", exp_extsc_type),
+            EXP_CHANNEL("_m", " Mid", " M"),
+            EXP_CHANNEL("_s", " Side", " S"),
+            EXP_AUDIO_METER("_m", " Mid", " M"),
+            EXP_AUDIO_METER("_s", " Side", " S"),
 
             PORTS_END
         };
@@ -336,7 +338,7 @@ namespace lsp
             clap_features_mono,
             E_INLINE_DISPLAY | E_DUMP_STATE,
             expander_mono_ports,
-            "dynamics/expander/single/mono.xml",
+            "dynamics/expander/single.xml",
             NULL,
             mono_plugin_port_groups,
             &expander_bundle
@@ -366,7 +368,7 @@ namespace lsp
             clap_features_stereo,
             E_INLINE_DISPLAY | E_DUMP_STATE,
             expander_stereo_ports,
-            "dynamics/expander/single/stereo.xml",
+            "dynamics/expander/single.xml",
             NULL,
             stereo_plugin_port_groups,
             &expander_bundle
@@ -396,7 +398,7 @@ namespace lsp
             clap_features_stereo,
             E_INLINE_DISPLAY | E_DUMP_STATE,
             expander_lr_ports,
-            "dynamics/expander/single/lr.xml",
+            "dynamics/expander/single.xml",
             NULL,
             stereo_plugin_port_groups,
             &expander_bundle
@@ -426,7 +428,7 @@ namespace lsp
             clap_features_stereo,
             E_INLINE_DISPLAY | E_DUMP_STATE,
             expander_ms_ports,
-            "dynamics/expander/single/ms.xml",
+            "dynamics/expander/single.xml",
             NULL,
             stereo_plugin_port_groups,
             &expander_bundle
@@ -457,7 +459,7 @@ namespace lsp
             clap_features_mono,
             E_INLINE_DISPLAY | E_DUMP_STATE,
             sc_expander_mono_ports,
-            "dynamics/expander/single/mono.xml",
+            "dynamics/expander/single.xml",
             NULL,
             mono_plugin_sidechain_port_groups,
             &expander_bundle
@@ -487,7 +489,7 @@ namespace lsp
             clap_features_stereo,
             E_INLINE_DISPLAY | E_DUMP_STATE,
             sc_expander_stereo_ports,
-            "dynamics/expander/single/stereo.xml",
+            "dynamics/expander/single.xml",
             NULL,
             stereo_plugin_sidechain_port_groups,
             &expander_bundle
@@ -517,7 +519,7 @@ namespace lsp
             clap_features_stereo,
             E_INLINE_DISPLAY | E_DUMP_STATE,
             sc_expander_lr_ports,
-            "dynamics/expander/single/lr.xml",
+            "dynamics/expander/single.xml",
             NULL,
             stereo_plugin_sidechain_port_groups,
             &expander_bundle
@@ -547,7 +549,7 @@ namespace lsp
             clap_features_stereo,
             E_INLINE_DISPLAY | E_DUMP_STATE,
             sc_expander_ms_ports,
-            "dynamics/expander/single/ms.xml",
+            "dynamics/expander/single.xml",
             NULL,
             stereo_plugin_sidechain_port_groups,
             &expander_bundle
