@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2024 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2024 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2025 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2025 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-plugins-gate
  * Created on: 3 авг. 2021 г.
@@ -25,7 +25,7 @@
 
 #define LSP_PLUGINS_GATE_VERSION_MAJOR       1
 #define LSP_PLUGINS_GATE_VERSION_MINOR       0
-#define LSP_PLUGINS_GATE_VERSION_MICRO       28
+#define LSP_PLUGINS_GATE_VERSION_MICRO       29
 
 #define LSP_PLUGINS_GATE_VERSION  \
     LSP_MODULE_VERSION( \
@@ -82,8 +82,8 @@ namespace lsp
 
         static const port_item_t gate_extsc_type[] =
         {
-            { "Internal",   "sidechain.internal"        },
             { "External",   "sidechain.external"        },
+            { "Internal",   "sidechain.internal"        },
             { "Link",       "sidechain.link"            },
             { NULL, NULL }
         };
@@ -101,16 +101,18 @@ namespace lsp
             BYPASS,             \
             IN_GAIN,            \
             OUT_GAIN,           \
-            SWITCH("pause", "Pause graph analysis", 0.0f), \
-            TRIGGER("clear", "Clear graph analysis")
+            SWITCH("showmx", "Show mix overlay", "Show mix bar", 0.0f), \
+            SWITCH("showsc", "Show sidechain overlay", "Show SC bar", 0.0f), \
+            SWITCH("pause", "Pause graph analysis", "Pause", 0.0f), \
+            TRIGGER("clear", "Clear graph analysis", "Clear")
 
         #define GATE_MS_COMMON  \
             GATE_COMMON,        \
-            SWITCH("msl", "Mid/Side listen", 0.0f)
+            SWITCH("msl", "Mid/Side listen", "M/S listen", 0.0f)
 
         #define GATE_SPLIT_COMMON \
-            SWITCH("ssplit", "Stereo split", 0.0f), \
-            COMBO("sscs", "Split sidechain source", gate_metadata::SC_SPLIT_SOURCE_DFL, gate_sc_split_sources)
+            SWITCH("ssplit", "Stereo split", "Stereo split", 0.0f), \
+            COMBO("sscs", "Split sidechain source", "Split SC source", gate_metadata::SC_SPLIT_SOURCE_DFL, gate_sc_split_sources)
 
         #define GATE_SHM_LINK_MONO \
             OPT_RETURN_MONO("link", "shml", "Side-chain shared memory link")
@@ -119,56 +121,56 @@ namespace lsp
             OPT_RETURN_STEREO("link", "shml_", "Side-chain shared memory link")
 
         #define GATE_MONO_CHANNEL(sc_type) \
-            COMBO("sci", "Sidechain input", gate_metadata::SC_TYPE_DFL, sc_type), \
-            COMBO("scm", "Sidechain mode", gate_metadata::SC_MODE_DFL, gate_sc_modes), \
-            CONTROL("sla", "Sidechain lookahead", U_MSEC, gate_metadata::LOOKAHEAD), \
-            SWITCH("scl", "Sidechain listen", 0.0f), \
-            LOG_CONTROL("scr", "Sidechain reactivity", U_MSEC, gate_metadata::REACTIVITY), \
-            AMP_GAIN100("scp", "Sidechain preamp", GAIN_AMP_0_DB), \
-            COMBO("shpm", "High-pass filter mode", 0, gate_filter_slope),      \
-            LOG_CONTROL("shpf", "High-pass filter frequency", U_HZ, gate_metadata::HPF),   \
-            COMBO("slpm", "Low-pass filter mode", 0, gate_filter_slope),      \
-            LOG_CONTROL("slpf", "Low-pass filter frequency", U_HZ, gate_metadata::LPF)
+            COMBO("sci", "Sidechain input", "SC input", gate_metadata::SC_TYPE_DFL, sc_type), \
+            COMBO("scm", "Sidechain mode", "SC mode", gate_metadata::SC_MODE_DFL, gate_sc_modes), \
+            CONTROL("sla", "Sidechain lookahead", "SC look", U_MSEC, gate_metadata::LOOKAHEAD), \
+            SWITCH("scl", "Sidechain listen", "SC listen", 0.0f), \
+            LOG_CONTROL("scr", "Sidechain reactivity", "SC react", U_MSEC, gate_metadata::REACTIVITY), \
+            AMP_GAIN100("scp", "Sidechain preamp", "SC preamp", GAIN_AMP_0_DB), \
+            COMBO("shpm", "High-pass filter mode", "HPF mode", 0, gate_filter_slope),      \
+            LOG_CONTROL("shpf", "High-pass filter frequency", "HPF freq", U_HZ, gate_metadata::HPF),   \
+            COMBO("slpm", "Low-pass filter mode", "LPF mode", 0, gate_filter_slope),      \
+            LOG_CONTROL("slpf", "Low-pass filter frequency", "LPF freq", U_HZ, gate_metadata::LPF)
 
-        #define GATE_STEREO_CHANNEL(id, label, sc_type) \
-            COMBO("sci" id, "Sidechain input" label, gate_metadata::SC_TYPE_DFL, sc_type), \
-            COMBO("scm" id, "Sidechain mode" label, gate_metadata::SC_MODE_DFL, gate_sc_modes), \
-            CONTROL("sla" id, "Sidechain lookahead" label, U_MSEC, gate_metadata::LOOKAHEAD), \
-            SWITCH("scl" id, "Sidechain listen" label, 0.0f), \
-            COMBO("scs" id, "Sidechain source" label, gate_metadata::SC_SOURCE_DFL, gate_sc_sources), \
-            LOG_CONTROL("scr" id, "Sidechain reactivity" label, U_MSEC, gate_metadata::REACTIVITY), \
-            AMP_GAIN100("scp" id, "Sidechain preamp" label, GAIN_AMP_0_DB), \
-            COMBO("shpm" id, "High-pass filter mode" label, 0, gate_filter_slope),      \
-            LOG_CONTROL("shpf" id, "High-pass filter frequency" label, U_HZ, gate_metadata::HPF),   \
-            COMBO("slpm" id, "Low-pass filter mode" label, 0, gate_filter_slope),      \
-            LOG_CONTROL("slpf" id, "Low-pass filter frequency" label, U_HZ, gate_metadata::LPF)
+        #define GATE_STEREO_CHANNEL(id, label, alias, sc_type) \
+            COMBO("sci" id, "Sidechain input" label, "SC input" alias, gate_metadata::SC_TYPE_DFL, sc_type), \
+            COMBO("scm" id, "Sidechain mode" label, "SC mode" alias, gate_metadata::SC_MODE_DFL, gate_sc_modes), \
+            CONTROL("sla" id, "Sidechain lookahead" label, "SC look" alias, U_MSEC, gate_metadata::LOOKAHEAD), \
+            SWITCH("scl" id, "Sidechain listen" label, "SC listen" alias, 0.0f), \
+            COMBO("scs" id, "Sidechain source" label, "SC source" alias, gate_metadata::SC_SOURCE_DFL, gate_sc_sources), \
+            LOG_CONTROL("scr" id, "Sidechain reactivity" label, "SC react" alias, U_MSEC, gate_metadata::REACTIVITY), \
+            AMP_GAIN100("scp" id, "Sidechain preamp" label, "SC preamp" alias, GAIN_AMP_0_DB), \
+            COMBO("shpm" id, "High-pass filter mode" label, "HPF mode " alias, 0, gate_filter_slope),      \
+            LOG_CONTROL("shpf" id, "High-pass filter frequency" label, "HPF freq" alias, U_HZ, gate_metadata::HPF),   \
+            COMBO("slpm" id, "Low-pass filter mode" label, "LPF mode" alias, 0, gate_filter_slope),      \
+            LOG_CONTROL("slpf" id, "Low-pass filter frequency" label, "LPF freq" alias, U_HZ, gate_metadata::LPF)
 
-        #define GATE_CHANNEL(id, label) \
-            SWITCH("gh" id, "Hysteresis" label, 0.0f), \
-            LOG_CONTROL("gt" id, "Curve threshold" label, U_GAIN_AMP, gate_metadata::THRESHOLD), \
-            LOG_CONTROL("gz" id, "Curve zone size" label, U_GAIN_AMP, gate_metadata::ZONE), \
-            LOG_CONTROL("ht" id, "Hysteresis threshold" label, U_GAIN_AMP, gate_metadata::H_THRESHOLD), \
-            LOG_CONTROL("hz" id, "Hysteresis zone size" label, U_GAIN_AMP, gate_metadata::ZONE), \
-            LOG_CONTROL("at" id, "Attack" label, U_MSEC, gate_metadata::ATTACK_TIME), \
-            LOG_CONTROL("rt" id, "Release" label, U_MSEC, gate_metadata::RELEASE_TIME), \
-            CONTROL("hold" id, "Hold time" label, U_MSEC, gate_metadata::HOLD_TIME), \
-            LOG_CONTROL("gr" id, "Reduction" label, U_GAIN_AMP, gate_metadata::REDUCTION), \
-            LOG_CONTROL("mk" id, "Makeup gain" label, U_GAIN_AMP, gate_metadata::MAKEUP), \
-            AMP_GAIN10("cdr" id, "Dry gain" label, GAIN_AMP_M_INF_DB),     \
-            AMP_GAIN10("cwt" id, "Wet gain" label, GAIN_AMP_0_DB), \
-            PERCENTS("cdw" id, "Dry/Wet balance" label, 100.0f, 0.1f), \
+        #define GATE_CHANNEL(id, label, alias) \
+            SWITCH("gh" id, "Hysteresis" label, "Hysteresis" alias, 0.0f), \
+            LOG_CONTROL("gt" id, "Curve threshold" label, "Thresh" alias, U_GAIN_AMP, gate_metadata::THRESHOLD), \
+            LOG_CONTROL("gz" id, "Curve zone size" label, "Zone" alias, U_GAIN_AMP, gate_metadata::ZONE), \
+            LOG_CONTROL("ht" id, "Hysteresis threshold" label, "Hyst thresh" alias, U_GAIN_AMP, gate_metadata::H_THRESHOLD), \
+            LOG_CONTROL("hz" id, "Hysteresis zone size" label, "Hyst zone" alias, U_GAIN_AMP, gate_metadata::ZONE), \
+            LOG_CONTROL("at" id, "Attack" label, "Att time" alias, U_MSEC, gate_metadata::ATTACK_TIME), \
+            LOG_CONTROL("rt" id, "Release" label, "Rel time" alias, U_MSEC, gate_metadata::RELEASE_TIME), \
+            CONTROL("hold" id, "Hold time" label, "Hold time" alias, U_MSEC, gate_metadata::HOLD_TIME), \
+            LOG_CONTROL("gr" id, "Reduction" label, "Reduction" alias, U_GAIN_AMP, gate_metadata::REDUCTION), \
+            LOG_CONTROL("mk" id, "Makeup gain" label, "Makeup" alias, U_GAIN_AMP, gate_metadata::MAKEUP), \
+            AMP_GAIN10("cdr" id, "Dry gain" label, "Dry" alias, GAIN_AMP_M_INF_DB),     \
+            AMP_GAIN10("cwt" id, "Wet gain" label, "Wet" alias, GAIN_AMP_0_DB), \
+            PERCENTS("cdw" id, "Dry/Wet balance" label, "Dry/Wet" alias, 100.0f, 0.1f), \
             METER_OUT_GAIN("gzs" id, "Zone start" label, GAIN_AMP_P_24_DB), \
             METER_OUT_GAIN("hts" id, "Hysteresis threshold start" label, GAIN_AMP_P_24_DB), \
             METER_OUT_GAIN("hzs" id, "Hysteresis zone start" label, GAIN_AMP_P_24_DB), \
             MESH("cg" id, "Curve graph" label, 2, gate_metadata::CURVE_MESH_SIZE), \
             MESH("hg" id, "Hysteresis graph" label, 2, gate_metadata::CURVE_MESH_SIZE)
 
-        #define GATE_AUDIO_METER(id, label) \
-            SWITCH("slv" id, "Sidechain level visibility" label, 1.0f), \
-            SWITCH("elv" id, "Envelope level visibility" label, 1.0f), \
-            SWITCH("grv" id, "Gain reduction visibility" label, 1.0f), \
-            SWITCH("ilv" id, "Input level visibility" label, 1.0f), \
-            SWITCH("olv" id, "Output level visibility" label, 1.0f), \
+        #define GATE_AUDIO_METER(id, label, alias) \
+            SWITCH("slv" id, "Sidechain level visibility" label, "Show SC" alias, 1.0f), \
+            SWITCH("elv" id, "Envelope level visibility" label, "Show Env" alias, 1.0f), \
+            SWITCH("grv" id, "Gain reduction visibility" label, "Show Gain" alias, 1.0f), \
+            SWITCH("ilv" id, "Input level visibility" label, "Show In" alias, 1.0f), \
+            SWITCH("olv" id, "Output level visibility" label, "Show Out" alias, 1.0f), \
             MESH("scg" id, "Sidechain graph" label, 2, gate_metadata::TIME_MESH_SIZE), \
             MESH("evg" id, "Envelope graph" label, 2, gate_metadata::TIME_MESH_SIZE), \
             MESH("grg" id, "Gain reduciton graph" label, 2, gate_metadata::TIME_MESH_SIZE + 4), \
@@ -187,8 +189,8 @@ namespace lsp
             GATE_SHM_LINK_MONO,
             GATE_COMMON,
             GATE_MONO_CHANNEL(gate_sc_type),
-            GATE_CHANNEL("", ""),
-            GATE_AUDIO_METER("", ""),
+            GATE_CHANNEL("", "", ""),
+            GATE_AUDIO_METER("", "", ""),
 
             PORTS_END
         };
@@ -199,10 +201,10 @@ namespace lsp
             GATE_SHM_LINK_STEREO,
             GATE_COMMON,
             GATE_SPLIT_COMMON,
-            GATE_STEREO_CHANNEL("", "", gate_sc_type),
-            GATE_CHANNEL("", ""),
-            GATE_AUDIO_METER("_l", " Left"),
-            GATE_AUDIO_METER("_r", " Right"),
+            GATE_STEREO_CHANNEL("", "", "", gate_sc_type),
+            GATE_CHANNEL("", "", ""),
+            GATE_AUDIO_METER("_l", " Left", " L"),
+            GATE_AUDIO_METER("_r", " Right", " R"),
 
             PORTS_END
         };
@@ -212,12 +214,12 @@ namespace lsp
             PORTS_STEREO_PLUGIN,
             GATE_SHM_LINK_STEREO,
             GATE_COMMON,
-            GATE_STEREO_CHANNEL("_l", " Left", gate_sc_type),
-            GATE_STEREO_CHANNEL("_r", " Right", gate_sc_type),
-            GATE_CHANNEL("_l", " Left"),
-            GATE_CHANNEL("_r", " Right"),
-            GATE_AUDIO_METER("_l", " Left"),
-            GATE_AUDIO_METER("_r", " Right"),
+            GATE_STEREO_CHANNEL("_l", " Left", " L", gate_sc_type),
+            GATE_STEREO_CHANNEL("_r", " Right", " R", gate_sc_type),
+            GATE_CHANNEL("_l", " Left", " L"),
+            GATE_CHANNEL("_r", " Right", " R"),
+            GATE_AUDIO_METER("_l", " Left", " L"),
+            GATE_AUDIO_METER("_r", " Right", " R"),
 
             PORTS_END
         };
@@ -227,12 +229,12 @@ namespace lsp
             PORTS_STEREO_PLUGIN,
             GATE_SHM_LINK_STEREO,
             GATE_MS_COMMON,
-            GATE_STEREO_CHANNEL("_m", " Mid", gate_sc_type),
-            GATE_STEREO_CHANNEL("_s", " Side", gate_sc_type),
-            GATE_CHANNEL("_m", " Mid"),
-            GATE_CHANNEL("_s", " Side"),
-            GATE_AUDIO_METER("_m", " Mid"),
-            GATE_AUDIO_METER("_s", " Side"),
+            GATE_STEREO_CHANNEL("_m", " Mid", " M", gate_sc_type),
+            GATE_STEREO_CHANNEL("_s", " Side", " S", gate_sc_type),
+            GATE_CHANNEL("_m", " Mid", " M"),
+            GATE_CHANNEL("_s", " Side", " S"),
+            GATE_AUDIO_METER("_m", " Mid", " M"),
+            GATE_AUDIO_METER("_s", " Side", " S"),
 
             PORTS_END
         };
@@ -244,8 +246,8 @@ namespace lsp
             GATE_SHM_LINK_MONO,
             GATE_COMMON,
             GATE_MONO_CHANNEL(gate_extsc_type),
-            GATE_CHANNEL("", ""),
-            GATE_AUDIO_METER("", ""),
+            GATE_CHANNEL("", "", ""),
+            GATE_AUDIO_METER("", "", ""),
 
             PORTS_END
         };
@@ -257,10 +259,10 @@ namespace lsp
             GATE_SHM_LINK_STEREO,
             GATE_COMMON,
             GATE_SPLIT_COMMON,
-            GATE_STEREO_CHANNEL("", "", gate_extsc_type),
-            GATE_CHANNEL("", ""),
-            GATE_AUDIO_METER("_l", " Left"),
-            GATE_AUDIO_METER("_r", " Right"),
+            GATE_STEREO_CHANNEL("", "", "", gate_extsc_type),
+            GATE_CHANNEL("", "", ""),
+            GATE_AUDIO_METER("_l", " Left", " L"),
+            GATE_AUDIO_METER("_r", " Right", " R"),
 
             PORTS_END
         };
@@ -271,12 +273,12 @@ namespace lsp
             PORTS_STEREO_SIDECHAIN,
             GATE_SHM_LINK_STEREO,
             GATE_COMMON,
-            GATE_STEREO_CHANNEL("_l", " Left", gate_extsc_type),
-            GATE_STEREO_CHANNEL("_r", " Right", gate_extsc_type),
-            GATE_CHANNEL("_l", " Left"),
-            GATE_CHANNEL("_r", " Right"),
-            GATE_AUDIO_METER("_l", " Left"),
-            GATE_AUDIO_METER("_r", " Right"),
+            GATE_STEREO_CHANNEL("_l", " Left", " L", gate_extsc_type),
+            GATE_STEREO_CHANNEL("_r", " Right", " R", gate_extsc_type),
+            GATE_CHANNEL("_l", " Left", " L"),
+            GATE_CHANNEL("_r", " Right", " R"),
+            GATE_AUDIO_METER("_l", " Left", " L"),
+            GATE_AUDIO_METER("_r", " Right", " R"),
 
             PORTS_END
         };
@@ -287,12 +289,12 @@ namespace lsp
             PORTS_STEREO_SIDECHAIN,
             GATE_SHM_LINK_STEREO,
             GATE_MS_COMMON,
-            GATE_STEREO_CHANNEL("_m", " Mid", gate_extsc_type),
-            GATE_STEREO_CHANNEL("_s", " Side", gate_extsc_type),
-            GATE_CHANNEL("_m", " Mid"),
-            GATE_CHANNEL("_s", " Side"),
-            GATE_AUDIO_METER("_m", " Mid"),
-            GATE_AUDIO_METER("_s", " Side"),
+            GATE_STEREO_CHANNEL("_m", " Mid", " M", gate_extsc_type),
+            GATE_STEREO_CHANNEL("_s", " Side", " S", gate_extsc_type),
+            GATE_CHANNEL("_m", " Mid", " M"),
+            GATE_CHANNEL("_s", " Side", " S"),
+            GATE_AUDIO_METER("_m", " Mid", " M"),
+            GATE_AUDIO_METER("_s", " Side", " S"),
 
             PORTS_END
         };
@@ -331,7 +333,7 @@ namespace lsp
             clap_features_mono,
             E_INLINE_DISPLAY,
             gate_mono_ports,
-            "dynamics/gate/single/mono.xml",
+            "dynamics/gate/single.xml",
             NULL,
             mono_plugin_port_groups,
             &gate_bundle
@@ -361,7 +363,7 @@ namespace lsp
             clap_features_stereo,
             E_INLINE_DISPLAY,
             gate_stereo_ports,
-            "dynamics/gate/single/stereo.xml",
+            "dynamics/gate/single.xml",
             NULL,
             stereo_plugin_port_groups,
             &gate_bundle
@@ -391,7 +393,7 @@ namespace lsp
             clap_features_stereo,
             E_INLINE_DISPLAY,
             gate_lr_ports,
-            "dynamics/gate/single/lr.xml",
+            "dynamics/gate/single.xml",
             NULL,
             stereo_plugin_port_groups,
             &gate_bundle
@@ -421,7 +423,7 @@ namespace lsp
             clap_features_stereo,
             E_INLINE_DISPLAY,
             gate_ms_ports,
-            "dynamics/gate/single/ms.xml",
+            "dynamics/gate/single.xml",
             NULL,
             stereo_plugin_port_groups,
             &gate_bundle
@@ -452,7 +454,7 @@ namespace lsp
             clap_features_mono,
             E_INLINE_DISPLAY,
             sc_gate_mono_ports,
-            "dynamics/gate/single/mono.xml",
+            "dynamics/gate/single.xml",
             NULL,
             mono_plugin_sidechain_port_groups,
             &gate_bundle
@@ -482,7 +484,7 @@ namespace lsp
             clap_features_stereo,
             E_INLINE_DISPLAY,
             sc_gate_stereo_ports,
-            "dynamics/gate/single/stereo.xml",
+            "dynamics/gate/single.xml",
             NULL,
             stereo_plugin_sidechain_port_groups,
             &gate_bundle
@@ -512,7 +514,7 @@ namespace lsp
             clap_features_stereo,
             E_INLINE_DISPLAY,
             sc_gate_lr_ports,
-            "dynamics/gate/single/lr.xml",
+            "dynamics/gate/single.xml",
             NULL,
             stereo_plugin_sidechain_port_groups,
             &gate_bundle
@@ -542,7 +544,7 @@ namespace lsp
             clap_features_stereo,
             E_INLINE_DISPLAY,
             sc_gate_ms_ports,
-            "dynamics/gate/single/ms.xml",
+            "dynamics/gate/single.xml",
             NULL,
             stereo_plugin_sidechain_port_groups,
             &gate_bundle
