@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2024 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2024 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2025 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2025 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-plugins-loud-comp
  * Created on: 3 авг. 2021 г.
@@ -25,7 +25,7 @@
 
 #define LSP_PLUGINS_LOUD_COMP_VERSION_MAJOR       1
 #define LSP_PLUGINS_LOUD_COMP_VERSION_MINOR       0
-#define LSP_PLUGINS_LOUD_COMP_VERSION_MICRO       24
+#define LSP_PLUGINS_LOUD_COMP_VERSION_MICRO       25
 
 #define LSP_PLUGINS_LOUD_COMP_VERSION  \
     LSP_MODULE_VERSION( \
@@ -77,17 +77,17 @@ namespace lsp
         };
 
         #define LOUD_COMP_COMMON \
-            AMP_GAIN("input", "Input gain", GAIN_AMP_0_DB, GAIN_AMP_P_72_DB), \
-            COMBO("std", "Loudness contour standard", loud_comp_metadata::STD_DFL, loud_comp_std), \
-            COMBO("fft", "FFT size", loud_comp_metadata::FFT_RANK_IDX_DFL, loud_comp_fft_rank), \
-            CONTROL("volume", "Output volume", U_DB, loud_comp_metadata::PHONS), \
-            SWITCH("refer", "Enable reference generator", 0.0f), \
-            COMBO("reftype", "Type of reference generator", 2.0f, loud_comp_generator), \
-            SWITCH("hclip", "Hard-clipping enable", 0.0f), \
-            CONTROL("hcrange", "Hard-clipping range", U_DB, loud_comp_metadata::HCRANGE), \
-            TRIGGER("hcclean", "Clean hard-clipping indicators"), \
+            AMP_GAIN("input", "Input gain", "Input gain", GAIN_AMP_0_DB, GAIN_AMP_P_72_DB), \
+            COMBO("std", "Loudness contour standard", "Standard", loud_comp_metadata::STD_DFL, loud_comp_std), \
+            COMBO("fft", "FFT size", "FFT size", loud_comp_metadata::FFT_RANK_IDX_DFL, loud_comp_fft_rank), \
+            CONTROL("volume", "Output volume", "Out volume", U_DB, loud_comp_metadata::PHONS), \
+            SWITCH("refer", "Enable reference generator", "Reference", 0.0f), \
+            COMBO("reftype", "Type of reference generator", "Ref type", 2.0f, loud_comp_generator), \
+            SWITCH("hclip", "Hard-clipping enable", "Hard clip on", 0.0f), \
+            CONTROL("hcrange", "Hard-clipping range", "Hard clip", U_DB, loud_comp_metadata::HCRANGE), \
+            TRIGGER("hcclean", "Clean hard-clipping indicators", "Clear hard clip"), \
             MESH("spec", "Level compensation frequency graph", 2, loud_comp_metadata::CURVE_MESH_SIZE), \
-            SWITCH("relspec", "Equalization curve is shown relative to the volume", 0.0f), \
+            SWITCH("relspec", "Equalization curve is shown relative to the volume", "Rel curve", 0.0f), \
             LUFS_METER("lufs_il", "Input signal LUFS", 24.0f), \
             LUFS_METER("lufs_ol", "Input signal LUFS", 24.0f)
 
