@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2024 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2024 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2025 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2025 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-plugins-oscillator
  * Created on: 3 авг. 2021 г.
@@ -25,7 +25,7 @@
 
 #define LSP_PLUGINS_OSCILLATOR_VERSION_MAJOR       1
 #define LSP_PLUGINS_OSCILLATOR_VERSION_MINOR       0
-#define LSP_PLUGINS_OSCILLATOR_VERSION_MICRO       24
+#define LSP_PLUGINS_OSCILLATOR_VERSION_MICRO       25
 
 #define LSP_PLUGINS_OSCILLATOR_VERSION  \
     LSP_MODULE_VERSION( \
@@ -90,23 +90,23 @@ namespace lsp
         {
             PORTS_MONO_PLUGIN,
             BYPASS,
-            LOG_CONTROL("freq", "Frequency", U_HZ, oscillator_metadata::FREQUENCY),
-            AMP_GAIN10("gain", "Output gain", 1.0f),
-            CONTROL("dcoff", "DC Offset", U_NONE, oscillator_metadata::DCOFFSET),
-            COMBO("scr", "DC Reference", oscillator_metadata::SC_DC_DFL, sc_dc_ref),
-            CYC_CONTROL("iniph", "Initial Phase", U_DEG, oscillator_metadata::INITPHASE),
-            COMBO("scm", "Operation Mode", oscillator_metadata::SC_MODE_DFL, sc_mode),
-            COMBO("scom", "Oversampler Mode", oscillator_metadata::SC_OVS_DFL, sc_oversampler_mode),
-            COMBO("scf", "Function", oscillator_metadata::SC_FUNC_DFL, sc_func),
-            SWITCH("invss", "Invert Squared Sinusoids", 0.0f),
-            SWITCH("invps", "Invert Parabolic Signal", 0.0f),
-            PERCENTS("rdtrt", "Duty Ratio", 50.0f, 0.025f),
-            PERCENTS("swdth", "Width", 50.0f, 0.025f),
-            PERCENTS("trsrt", "Raise Ratio", 25.0f, 0.025f),
-            PERCENTS("tflrt", "Fall Ratio", 25.0f, 0.025f),
-            PERCENTS("tpwrt", "Positive Width", 25.0f, 0.025f),
-            PERCENTS("tnwrt", "Negative Width", 25.0f, 0.025f),
-            PERCENTS("pwdth", "Width", 100.0f, 0.025f),
+            LOG_CONTROL("freq", "Frequency", "Frequency", U_HZ, oscillator_metadata::FREQUENCY),
+            AMP_GAIN10("gain", "Output gain", "Output gain", 1.0f),
+            CONTROL("dcoff", "DC Offset", "DC offset", U_NONE, oscillator_metadata::DCOFFSET),
+            COMBO("scr", "DC Reference", "DC reference", oscillator_metadata::SC_DC_DFL, sc_dc_ref),
+            CYC_CONTROL("iniph", "Initial Phase", "Phase", U_DEG, oscillator_metadata::INITPHASE),
+            COMBO("scm", "Operation Mode", "Mode", oscillator_metadata::SC_MODE_DFL, sc_mode),
+            COMBO("scom", "Oversampler Mode", "Oversample", oscillator_metadata::SC_OVS_DFL, sc_oversampler_mode),
+            COMBO("scf", "Function", "Function", oscillator_metadata::SC_FUNC_DFL, sc_func),
+            SWITCH("invss", "Invert Squared Sinusoids", "Inv sqr sine", 0.0f),
+            SWITCH("invps", "Invert Parabolic Signal", "Inv paraboas", 0.0f),
+            PERCENTS("rdtrt", "Duty Ratio", "Duty ratio", 50.0f, 0.025f),
+            PERCENTS("swdth", "Width", "Width", 50.0f, 0.025f),
+            PERCENTS("trsrt", "Raise Ratio", "Raise ratio", 25.0f, 0.025f),
+            PERCENTS("tflrt", "Fall Ratio", "Fall ratio", 25.0f, 0.025f),
+            PERCENTS("tpwrt", "Positive Width", "Positive Width", 25.0f, 0.025f),
+            PERCENTS("tnwrt", "Negative Width", "Negative Width", 25.0f, 0.025f),
+            PERCENTS("pwdth", "Parabolic Width", "Par Width", 100.0f, 0.025f),
             MESH("ow", "Output wave", 2, oscillator_metadata::HISTORY_MESH_SIZE),
 
             PORTS_END
